@@ -5,9 +5,11 @@ use utf8;
 use Ukigumo::Client;
 use Ukigumo::Client::VC::Git;
 use Ukigumo::Client::Executor::Perl;
+use Ukigumo::Agent::Logger;
 use Coro;
 use Coro::AnyEvent;
 use POSIX qw/SIGTERM SIGKILL/;
+use Log::Minimal;
 
 use Mouse;
 
@@ -17,6 +19,13 @@ has 'server_url' => ( is => 'rw', isa => 'Str', required => 1 );
 has job_queue => (is => 'ro', default => sub { +[ ] });
 has max_children => ( is => 'ro', default => 1 );
 has timeout => (is => 'rw', isa => 'Int', default => 0);
+has logger => (
+    is      => 'ro',
+    isa     => 'Ukigumo::Agent::Logger',
+    default => sub {
+        Ukigumo::Agent::Logger->new
+    },
+);
 
 no Mouse;
 
@@ -39,20 +48,34 @@ sub run_job {
     my ($self, $args) = @_;
     Carp::croak "Missing args" unless $args;
 
+    my $repository = $args->{repository} || die;
+    my $branch     = $args->{branch} || die;
+
+    my $vc = Ukigumo::Client::VC::Git->new(
+        branch     => $branch,
+        repository => $repository,
+    );
+    my $client = Ukigumo::Client->new(
+        workdir     => $self->work_dir,
+        vc          => $vc,
+        executor    => Ukigumo::Client::Executor::Perl->new(),
+        server_url  => $self->server_url,
+        compare_url => $args->{compare_url},
+        repository_owner => $args->{repository_owner},
+        repository_name  => $args->{repository_name},
+    );
+
+    my $client_log_filename = $client->logfh->filename;
+
+    my $timeout_timer;
+
     my $pid = fork();
     if (!defined $pid) {
         die "Cannot fork: $!";
     }
 
-    my $repository = $args->{repository} || die;
-    my $branch     = $args->{branch} || die;
-
-    my $timeout_timer;
-
-    my $client;
-
     if ($pid) {
-        print "Spawned $pid\n";
+        $self->logger->infof("Spawned $pid");
         $self->{children}->{$pid} = +{
             child => AE::child($pid, unblock_sub {
                 my ($pid, $status) = @_;
@@ -71,18 +94,18 @@ sub run_job {
                             kill SIGKILL, $pid;
                         }
                     }
-                    $client->report_timeout;
-                    return;
+                    $self->logger->warnf("[child] timeout");
+                    eval { $client->report_timeout($client_log_filename) };
                 }
 
-                print "[child exit] pid: $pid, status: $status\n";
+                $self->logger->infof("[child exit] pid: $pid, status: $status");
                 delete $self->{children}->{$pid};
 
                 if ($self->count_children < $self->max_children && @{$self->job_queue} > 0) {
-                    print "[child exit] run new job\n";
+                    $self->logger->infof("[child exit] run new job");
                     $self->run_job($self->pop_job);
                 } else {
-                    print "[child exit] There is no jobs. sleep...\n";
+                    $self->_take_a_break();
                 }
             }),
             job => $args,
@@ -95,24 +118,9 @@ sub run_job {
             };
         }
     } else {
-        eval {
-            my $vc = Ukigumo::Client::VC::Git->new(
-                branch => $branch,
-                repository => $repository,
-            );
-            $client = Ukigumo::Client->new(
-                workdir     => $self->work_dir,
-                vc          => $vc,
-                executor    => Ukigumo::Client::Executor::Perl->new(),
-                server_url  => $self->server_url,
-                compare_url => $args->{compare_url},
-                repository_owner => $args->{repository_owner},
-                repository_name  => $args->{repository_name},
-            );
-            $client->run();
-        };
-        print "[child] error: $@\n" if $@;
-        print "[child] finished to work\n";
+        eval { $client->run() };
+        $self->logger->warnf("[child] error: $@") if $@;
+        $self->logger->infof("[child] finished to work");
         exit;
     }
 }
@@ -128,5 +136,10 @@ sub register_job {
     }
 }
 
+sub _take_a_break {
+    my ($self) = @_;
+    $self->logger->infof("[child exit] There is no jobs. sleep...");
+}
+
 1;
 
